﻿using System;
using System.Net;
using System.Windows;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Drawing;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.Wpf;

namespace WmtsLayer
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            map.MapUnit = GeographyUnit.Meter;
            map.CurrentExtent = new RectangleShape(1254901.87822449, 6785639.16296541, 1734313.72055747, 6441979.14333386);

            ThinkGeo.MapSuite.Layers.WmtsLayer wmtsLayer = new ThinkGeo.MapSuite.Layers.WmtsLayer();
            wmtsLayer.DrawingExceptionMode = DrawingExceptionMode.DrawException;
            wmtsLayer.WmtsSeverEncodingType = ThinkGeo.MapSuite.Layers.WmtsSeverEncodingType.Kvp;
            wmtsLayer.ServerUris.Add(new Uri("https://geodienste.sachsen.de/wmts_geosn_webatlas-sn/guest"));
            wmtsLayer.ActiveLayerName = "WMTS";
            wmtsLayer.ActiveStyleName = "default";
            wmtsLayer.TileMatrixSetName = "grid_3857";
            wmtsLayer.OutputFormat = "image/png";

            wmtsLayer.SendingWebRequest += WmtsLayer_SendingWebRequest;

            LayerOverlay layerOverlay = new LayerOverlay();
            layerOverlay.Layers.Add(wmtsLayer);

            map.Overlays.Add(layerOverlay);
            map.Refresh();
        }

        private void WmtsLayer_SendingWebRequest(object sender, SendingWebRequestEventArgs e)
        {
            System.Diagnostics.Debug.WriteLine(e.WebRequest.RequestUri.ToString());
            string originalURL = e.WebRequest.RequestUri.ToString();
            string newURL = originalURL.Replace("TileMatrix=grid_3857:1", "TileMatrix=1"); // Replace 10 to 19
            newURL = newURL.Replace("TileMatrix=grid_3857:", "TileMatrix=0"); // Replace 0 to 9            
            e.WebRequest = HttpWebRequest.Create(newURL);
            System.Diagnostics.Debug.WriteLine(e.WebRequest.RequestUri.ToString());
        }
    }
}
